import pytest
from hqporner_api.api import Video



@pytest.mark.asyncio
async def test_video_all():
    url = "https://hqporner.com/hdporn/99748-exercise_bike_Mila_Azul.html"
    video = await Video.create(url)
    assert isinstance(video.title, str) and len(video.title) > 0
    assert isinstance(video.pornstars, list) and len(video.pornstars) > 0
    assert isinstance(video.length, str) and len(video.length) > 0
    assert isinstance(video.tags, list) and len(video.tags) > 0
    assert isinstance(await video.video_qualities(), list) and len(await video.video_qualities()) > 0
    assert isinstance(await video.direct_download_urls(), list) and len(await video.direct_download_urls()) > 0
    assert isinstance(await video.get_thumbnails(), list) and len(await video.get_thumbnails()) == 11












import pytest
from ..api import Client


@pytest.mark.asyncio
async def test_basic_search():
    client = Client()
    query = "Mia Khalifa"

    videos = await client.search_videos(query)

    for video in videos:
        assert isinstance(video.title, str) and len(video.title) > 0



import pytest
from hqporner_api.api import Client, Sort

client = Client()

@pytest.mark.asyncio
async def test_all():

    top_porn_all = await client.get_top_porn(sort_by=Sort.ALL_TIME)

    for idx, video in enumerate(top_porn_all):
        assert isinstance(video.title, str) and len(video.title) > 0
        if idx == 3:
            break

    top_porn_week = await client.get_top_porn(sort_by=Sort.WEEK)

    for idx, video in enumerate(top_porn_week):
        assert isinstance(video.title, str) and len(video.title) > 0
        if idx == 3:
            break


    top_porn_month = await client.get_top_porn(sort_by=Sort.MONTH)

    for idx, video in enumerate(top_porn_month):
        assert isinstance(video.title, str) and len(video.title) > 0
        if idx == 3:
            break


    all_categories = await client.get_all_categories()
    assert isinstance(all_categories, list) and len(all_categories) > 20


    random_video = await client.get_random_video()
    assert isinstance(random_video.title, str) and len(random_video.title) > 0

    name = "anissa-kate"

    actress = await client.get_videos_by_actress(name)
    for idx, video in enumerate(actress):
        assert isinstance(video.title, str) and len(video.title) > 0
        if idx == 3:
            break

    videos = await client.get_brazzers_videos()
    for idx, video in enumerate(videos):
        assert isinstance(video.title, str) and len(video.title) > 0
        if idx == 3:
            break



import pytest
import asyncio


@pytest.fixture(scope="session")
def event_loop():
    try:
        loop = asyncio.get_running_loop()
    except RuntimeError:
        loop = asyncio.new_event_loop()
    yield loop
    loop.close()


import pytest
from ..api import Client

@pytest.mark.asyncio
async def test_downloads():
    client = Client()

    url = "https://hqporner.com/hdporn/99748-exercise_bike_Mila_Azul.html"
    url_2 = "https://hqporner.com/hdporn/118926-very_easy_on_the_eyes.html"
    url_3 = "https://hqporner.com/hdporn/116797-loss_by_loss_makes_a_big_win.html"

    video = await client.get_video(url)
    video_2 = await client.get_video(url_2)
    video_3 = await client.get_video(url_3)

    assert await video.download(quality="best") is True

    assert await video_2.download(quality="half") is True

    assert await video_3.download(quality="worst") is True